==> qtjambi-qt3drender-6.6.0-sources.jar: io/qt/qt3d/render/QTextureBuffer.java <==
package io.qt.qt3d.render;

import io.qt.*;


/**
 * <p>A QAbstractTexture with a TargetBuffer target format</p>
 * <p>Java wrapper for Qt class <code><a href="https://doc.qt.io/qt/qt3drender-qtexturebuffer.html">Qt3DRender::QTextureBuffer</a></code></p>
 */
public class QTextureBuffer extends io.qt.qt3d.render.QAbstractTexture
{
    /**
     * This variable stores the meta-object for the class.
     */
    public static final io.qt.core.@NonNull QMetaObject staticMetaObject = io.qt.core.QMetaObject.forType(QTextureBuffer.class);
    
    
    /**
     * <p>See <code><a href="https://doc.qt.io/qt/qt3drender-qtexturebuffer.html#QTextureBuffer">Qt3DRender::QTextureBuffer::<wbr>QTextureBuffer(Qt3DCore::QNode*)</a></code></p>
     */
    @SuppressWarnings({"exports"})
    public QTextureBuffer(io.qt.qt3d.core.@Nullable QNode parent){
        super((QPrivateConstructor)null);
        initialize_native(this, parent);
    }
    
    private native static void initialize_native(QTextureBuffer instance, io.qt.qt3d.core.QNode parent);
    
    /**
     * Constructor for internal use only.
     * @param p expected to be <code>null</code>.
     * @hidden
     */
    @NativeAccess
    protected QTextureBuffer(QPrivateConstructor p) { super(p); } 
    
    /**
     * Constructor for internal use only.
     * @hidden
     * It is not allowed to call the declarative constructor from inside Java.
     */
    @NativeAccess
    protected QTextureBuffer(QDeclarativeConstructor constructor) {
        super((QPrivateConstructor)null);
        initialize_native(this, constructor);
    } 
    
    @QtUninvokable
    private static native void initialize_native(QTextureBuffer instance, QDeclarativeConstructor constructor);
    
    
    /**
     * <p>Overloaded constructor for {@link #QTextureBuffer(io.qt.qt3d.core.QNode)}
     *  with <code>parent = null</code>.</p>
     */
    public QTextureBuffer() {
        this((io.qt.qt3d.core.QNode)null);
    }
}

==> qtjambi-qt3drender-6.7.0-sources.jar: io/qt/qt3d/render/QTextureBuffer.java <==
package io.qt.qt3d.render;

import io.qt.*;


/**
 * <p>A QAbstractTexture with a TargetBuffer target format</p>
 * <p>Java wrapper for Qt class <code><a href="https://doc.qt.io/qt/qt3drender-qtexturebuffer.html">Qt3DRender::QTextureBuffer</a></code></p>
 */
public class QTextureBuffer extends io.qt.qt3d.render.QAbstractTexture
{
    /**
     * This variable stores the meta-object for the class.
     */
    public static final io.qt.core.@NonNull QMetaObject staticMetaObject = io.qt.core.QMetaObject.forType(QTextureBuffer.class);
    
    
    /**
     * <p>See <code><a href="https://doc.qt.io/qt/qt3drender-qtexturebuffer.html#QTextureBuffer">Qt3DRender::QTextureBuffer::<wbr/>QTextureBuffer(Qt3DCore::QNode*)</a></code></p>
     */
    @SuppressWarnings({"exports"})
    public QTextureBuffer(io.qt.qt3d.core.@Nullable QNode parent){
        super((QPrivateConstructor)null);
        initialize_native(this, parent);
    }
    
    private native static void initialize_native(QTextureBuffer instance, io.qt.qt3d.core.QNode parent);
    
    /**
     * Constructor for internal use only.
     * @param p expected to be <code>null</code>.
     * @hidden
     */
    @NativeAccess
    protected QTextureBuffer(QPrivateConstructor p) { super(p); } 
    
    /**
     * Constructor for internal use only.
     * It is not allowed to call the declarative constructor from inside Java.
     * @hidden
     */
    @NativeAccess
    protected QTextureBuffer(QDeclarativeConstructor constructor) {
        super((QPrivateConstructor)null);
        initialize_native(this, constructor);
    } 
    
    @QtUninvokable
    private static native void initialize_native(QTextureBuffer instance, QDeclarativeConstructor constructor);
    
    
    /**
     * <p>Overloaded constructor for {@link #QTextureBuffer(io.qt.qt3d.core.QNode)}
     *  with <code>parent = null</code>.</p>
     */
    public QTextureBuffer() {
        this((io.qt.qt3d.core.QNode)null);
    }
}
